@@ -1,15 +1,17 @@
 <?php
 /**
- * $Horde: forwards/index.php,v 1.17.2.2 2007/01/02 13:54:05 jan Exp $
+ * $Horde: forwards/index.php,v 1.17.2.4 2009/01/06 15:22:46 jan Exp $
  *
- * Copyright 2001-2007 Eric Rostetter <eric.rostetter@physics.utexas.edu>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSDL). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
+ *
+ * @author Eric Rostetter <eric.rostetter@physics.utexas.edu>
  */
 
 @define('FORWARDS_BASE', dirname(__FILE__));
-$forwards_configured = (@is_readable(FORWARDS_BASE . '/config/conf.php'));
+$forwards_configured = (is_readable(FORWARDS_BASE . '/config/conf.php'));
 
 if (!$forwards_configured) {
     require FORWARDS_BASE . '/../lib/Test.php';
